@@ -42,6 +42,15 @@ sub remove_extension {
    $self->remove_forward ($ext);
 }
 
+=item B<disco_features>
+
+This method can be overwritten by the extension and should return
+a list of namespace URIs of the features that the extension enables.
+
+=cut
+
+sub disco_features { }
+
 =back
 
 =head1 AUTHOR
